# Customize Widgets

Namespace: `core/customize-widgets`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/customize-widgets/src/store/selectors.js) -->

### isInserterOpened

Returns true if the inserter is opened.

_Usage_

```js
import { store as customizeWidgetsStore } from '@wordpress/customize-widgets';
import { __ } from '@wordpress/i18n';
import { useSelect } from '@wordpress/data';

const ExampleComponent = () => {
	const { isInserterOpened } = useSelect(
		( select ) => select( customizeWidgetsStore ),
		[]
	);

	return isInserterOpened()
		? __( 'Inserter is open' )
		: __( 'Inserter is closed.' );
};
```

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the inserter is opened.

<!-- END TOKEN(Autogenerated selectors|../../../packages/customize-widgets/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/customize-widgets/src/store/actions.js) -->

### setIsInserterOpened

Returns an action object used to open/close the inserter.

_Usage_

```js
import { useState } from 'react';
import { store as customizeWidgetsStore } from '@wordpress/customize-widgets';
import { __ } from '@wordpress/i18n';
import { useDispatch } from '@wordpress/data';
import { Button } from '@wordpress/components';

const ExampleComponent = () => {
	const { setIsInserterOpened } = useDispatch( customizeWidgetsStore );
	const [ isOpen, setIsOpen ] = useState( false );

	return (
		<Button
			onClick={ () => {
				setIsInserterOpened( ! isOpen );
				setIsOpen( ! isOpen );
			} }
		>
			{ __( 'Open/close inserter' ) }
		</Button>
	);
};
```

_Parameters_

-   _value_ `boolean|Object`: Whether the inserter should be opened (true) or closed (false). To specify an insertion point, use an object.
-   _value.rootClientId_ `string`: The root client ID to insert at.
-   _value.insertionIndex_ `number`: The index to insert at.

_Returns_

-   `Object`: Action object.

<!-- END TOKEN(Autogenerated actions|../../../packages/customize-widgets/src/store/actions.js) -->
